Crate minigrep_kashi754

source ·
Minigrep_kashi754

minigrep_kashi754 is a lightweight implementation of the popular grep command line tool. Built as my first project, it is not meant to be used in production.

Structs

  • Configuration struct for the tool Stores a query, path to a file, and an optional flag to perform the search case sensitive or not.

Functions

  • Searches the input string by line for a given term and returns a vector of all lines that contain the specified term.
  • Searches the input string by line for a given term as a case insensitive search and returns a vector of all lines that contain the specified term.